Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "SmilesMatcherInterface");
;//5.0.1-v7 Mon May 19 13:18:24 CDT 2025
